@@ -1,6 +1,6 @@
 package Dancer2::Plugin::Auth::Extensible;
 
-our $VERSION = '0.602';
+our $VERSION = '0.610';
 
 use strict;
 use warnings;
@@ -1768,7 +1768,7 @@ Documentation fix by Vince Willems.
 
 Henk van Oers (GH #8, #13).
 
-Andrew Beverly (GH #6, #7, #10, #17, #22, #24, #25, #26, #53).
+Andrew Beverly (GH #6, #7, #10, #17, #22, #24, #25, #26).
 This includes support for creating and editing users and manage user passwords.
 
 Gabor Szabo (GH #11, #16, #18).
